@@ -1,5 +1,4 @@
 package Catalyst::Helper::View::Email;
-our $VERSION = '0.21_01';
 
 use strict;
 
@@ -7,13 +6,9 @@ use strict;
 
 Catalyst::Helper::View::Email - Helper for Email Views
 
-=head1 VERSION
-
-version 0.21_01
-
 =head1 SYNOPSIS
 
-    $ script/myapp_create.pl view Email Email
+    script/create.pl view Email Email
 
 =head1 DESCRIPTION
 
@@ -86,4 +81,4 @@ it under the same terms as Perl itself.
 
 =cut
 
-1;
\ No newline at end of file
+1;
